Writing the binary file
-----------------------
The objects described above are Python representation of the information to be included in a DLIS file.
Subsections below explain how these objects are converted to bytes, which then become a part of the created file.

.. toctree::
   :maxdepth: 2

   dlisfileobject
   passingdata
   dliswriterobject
   convertingtobytes
